Crate prototty [−] [src]
Modules
| colours | |
| inputs |
Structs
| Coord |
General purpose coordinate for use within prototty crates. |
| CoordIter |
Iterates over all the coordinates in a grid from top to bottom, and left to right within each row. |
| Rgb24 | |
| Size |
Used to describe the size of a prototty view, and of a prototty context, in cells.
A size cannot be created which would contain un-addressable cells.
That is, the maximum size has a width and height of one greater than the maximum |
Enums
| Input |
An input event |
Traits
| Renderer |
Trait to implement for renderers that take data and a view that knows how to render the data to a grid, and actually draws the result. |
| View |
Defines a method for rendering a |
| ViewCell |
A cell that a view can write to |
| ViewGrid |
A grid of cells |
| ViewSize |
Report the size of a |